@@ -8,6 +8,8 @@
  * @copyright (c) 2014, Stefan Klemm
  */
 
+namespace OCA\Bookmarks\AppInfo;
+
 /**
  * Create your routes in here. The name is the lowercase name of the controller
  * without the controller part, the stuff after the hash is the method.
@@ -26,6 +28,8 @@ return [
 		['name' => 'web_view#index', 'url' => '/tags/{tags}', 'verb' => 'GET', 'postfix' => 'tags'],
 		['name' => 'web_view#index', 'url' => '/untagged', 'verb' => 'GET', 'postfix' => 'untagged'],
 		['name' => 'web_view#index', 'url' => '/bookmarklet', 'verb' => 'GET', 'postfix' => 'bookmarklet'],
+		['name' => 'web_view#service_worker', 'url' => '/service-worker.js', 'verb' => 'GET'],
+		['name' => 'web_view#manifest', 'url' => '/manifest.webmanifest', 'verb' => 'GET'],
 
 		//internal REST API
 		['name' => 'internal_bookmark#get_bookmarks', 'url' => '/bookmark', 'verb' => 'GET'],
