@@ -81,7 +81,7 @@ class BookmarkMapper extends QBMapper {
 	public function find(int $id): Entity {
 		$qb = $this->db->getQueryBuilder();
 		$qb
-			->select('*')
+			->select(Bookmark::$columns)
 			->from('bookmarks')
 			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)));
 
@@ -127,11 +127,9 @@ class BookmarkMapper extends QBMapper {
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tags', 't', $qb->expr()->eq('t.bookmark_id', 'b.id'))
 			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->eq('tr.id', 'b.id'))
-			->leftJoin('tr', 'bookmarks_shares', 's', $qb->expr()->eq('tr.parent_folder', 's.folder_id'))
-			->leftJoin('s', 'bookmarks_shared_folders', 'p', $qb->expr()->eq('s.id', 'p.share_id'))
+			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
 			->where($qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)))
-			->orWhere($qb->expr()->eq('p.user_id', $qb->createPositionalParameter($userId)));
-
+			->orWhere($qb->expr()->eq('sf.user_id', $qb->createPositionalParameter($userId)));
 
 		$this->_findBookmarksBuildFilter($qb, $filters, $params);
 		$this->_queryBuilderSortAndPaginate($qb, $params);
@@ -162,9 +160,9 @@ class BookmarkMapper extends QBMapper {
 		$sqlSortColumn = $params->getSortBy('lastmodified', Bookmark::$columns);
 
 		if ($sqlSortColumn === 'title') {
-			$qb->orderBy($qb->createFunction('UPPER(`title`)'), 'ASC');
+			$qb->orderBy($qb->createFunction('UPPER(`b`.`title`)'), 'ASC');
 		} else {
-			$qb->orderBy($sqlSortColumn, 'DESC');
+			$qb->orderBy('b.'.$sqlSortColumn, 'DESC');
 		}
 
 		if ($params->getLimit() !== -1) {
@@ -245,12 +243,19 @@ class BookmarkMapper extends QBMapper {
 	 */
 	public function findByTag($userId, string $tag, QueryParameters $params): array {
 		$qb = $this->db->getQueryBuilder();
-		$qb->select(Bookmark::$columns);
+		$qb->select(array_map(static function($col) {
+			return 'b.'.$col;
+		}, Bookmark::$columns));
 
 		$qb
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tags', 't', $qb->expr()->eq('t.bookmark_id', 'b.id'))
-			->where($qb->expr()->eq('user_id', $qb->createPositionalParameter($userId)))
+			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->eq('tr.id', 'b.id'))
+			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
+			->where($qb->expr()->orX(
+				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
+				$qb->expr()->eq('sf.user_id', $qb->createPositionalParameter($userId))
+			))
 			->andWhere($qb->expr()->eq('t.tag', $qb->createPositionalParameter($tag)));
 
 		$this->_queryBuilderSortAndPaginate($qb, $params);
@@ -260,12 +265,19 @@ class BookmarkMapper extends QBMapper {
 
 	private function _findByTags($userId): IQueryBuilder {
 		$qb = $this->db->getQueryBuilder();
-		$qb->select(Bookmark::$columns);
+		$qb->select(array_map(static function($col) {
+			return 'b.'.$col;
+		}, Bookmark::$columns));
 
 		$qb
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tags', 't', $qb->expr()->eq('t.bookmark_id', 'b.id'))
-			->where($qb->expr()->eq('user_id', $qb->createPositionalParameter($userId)));
+			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->eq('tr.id', 'b.id'))
+			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
+			->where($qb->expr()->orX(
+				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
+				$qb->expr()->eq('sf.user_id', $qb->createPositionalParameter($userId))
+			));
 
 		return $qb;
 	}
@@ -291,7 +303,9 @@ class BookmarkMapper extends QBMapper {
 			$expr[] = $qb->expr()->iLike($tagsCol, $qb->createPositionalParameter('%' . $this->db->escapeLikeParameter($tag) . '%'));
 		}
 		$filterExpression = call_user_func_array([$qb->expr(), 'andX'], $expr);
-		$qb->groupBy(...Bookmark::$columns);
+		$qb->groupBy(...array_map(static function($col) {
+			return 'b.'.$col;
+		}, Bookmark::$columns));
 		$qb->having($filterExpression);
 
 		$this->_queryBuilderSortAndPaginate($qb, $params);
@@ -398,7 +412,7 @@ class BookmarkMapper extends QBMapper {
 	 */
 	public function findPendingPreviews(int $limit, int $stalePeriod): array {
 		$qb = $this->db->getQueryBuilder();
-		$qb->select('*');
+		$qb->select(Bookmark::$columns);
 		$qb->from('bookmarks', 'b');
 		$qb->where($qb->expr()->lt('last_preview', $qb->createPositionalParameter(time() - $stalePeriod)));
 		$qb->orWhere($qb->expr()->isNull('last_preview'));
